GIMBAL_DEVICE_ATTITUDE_STATUS_DATA

Struct GIMBAL_DEVICE_ATTITUDE_STATUS_DATA 

pub struct GIMBAL_DEVICE_ATTITUDE_STATUS_DATA {
    pub time_boot_ms: u32,
    pub q: [f32; 4],
    pub angular_velocity_x: f32,
    pub angular_velocity_y: f32,
    pub angular_velocity_z: f32,
    pub failure_flags: GimbalDeviceErrorFlags,
    pub flags: GimbalDeviceFlags,
    pub target_system: u8,
    pub target_component: u8,
    pub delta_yaw: f32,
    pub delta_yaw_velocity: f32,
    pub gimbal_device_id: u8,
}
Available on crate feature dialect-ualberta only.
Message reporting the status of a gimbal device. This message should be broadcast by a gimbal device component at a low regular rate (e.g. 5 Hz). For the angles encoded in the quaternion and the angular velocities holds: If the flag GIMBAL_DEVICE_FLAGS_YAW_IN_VEHICLE_FRAME is set, then they are relative to the vehicle heading (vehicle frame). If the flag GIMBAL_DEVICE_FLAGS_YAW_IN_EARTH_FRAME is set, then they are relative to absolute North (earth frame). If neither of these flags are set, then (for backwards compatibility) it holds: If the flag GIMBAL_DEVICE_FLAGS_YAW_LOCK is set, then they are relative to absolute North (earth frame), else they are relative to the vehicle heading (vehicle frame). Other conditions of the flags are not allowed. The quaternion and angular velocities in the other frame can be calculated from delta_yaw and delta_yaw_velocity as q_earth = q_delta_yaw * q_vehicle and w_earth = w_delta_yaw_velocity + w_vehicle (if not NaN). If neither the GIMBAL_DEVICE_FLAGS_YAW_IN_VEHICLE_FRAME nor the GIMBAL_DEVICE_FLAGS_YAW_IN_EARTH_FRAME flag is set, then (for backwards compatibility) the data in the delta_yaw and delta_yaw_velocity fields are to be ignored. New implementations should always set either GIMBAL_DEVICE_FLAGS_YAW_IN_VEHICLE_FRAME or GIMBAL_DEVICE_FLAGS_YAW_IN_EARTH_FRAME, and always should set delta_yaw and delta_yaw_velocity either to the proper value or NaN.

ID: 285

Fields

time_boot_ms: u32

Timestamp (time since system boot).

q: [f32; 4]

Quaternion components, w, x, y, z (1 0 0 0 is the null-rotation). The frame is described in the message description.

angular_velocity_x: f32

X component of angular velocity (positive: rolling to the right). The frame is described in the message description. NaN if unknown.

angular_velocity_y: f32

Y component of angular velocity (positive: pitching up). The frame is described in the message description. NaN if unknown.

angular_velocity_z: f32

Z component of angular velocity (positive: yawing to the right). The frame is described in the message description. NaN if unknown.

failure_flags: GimbalDeviceErrorFlags

Failure flags (0 for no failure)

flags: GimbalDeviceFlags

Current gimbal flags set.

target_system: u8

System ID

target_component: u8

Component ID

delta_yaw: f32

Yaw angle relating the quaternions in earth and body frames (see message description). NaN if unknown.

delta_yaw_velocity: f32

Yaw angular velocity relating the angular velocities in earth and body frames (see message description). NaN if unknown.

gimbal_device_id: u8

This field is to be used if the gimbal manager and the gimbal device are the same component and hence have the same component ID. This field is then set a number between 1-6. If the component ID is separate, this field is not required and must be set to 0.

Implementations

Source

impl GIMBAL_DEVICE_ATTITUDE_STATUS_DATA

pub const ENCODED_LEN: usize = 49usize

pub const DEFAULT: Self

pub fn random<R: RngCore>(rng: &mut R) -> Self

Available on crate feature arbitrary only.