GimbalManagerCapFlags

Struct GimbalManagerCapFlags 

pub struct GimbalManagerCapFlags(/* private fields */);
Available on crate feature dialect-ualberta only.
Gimbal manager high level capability flags (bitmap). The first 16 bits are identical to the GIMBAL_DEVICE_CAP_FLAGS. However, the gimbal manager does not need to copy the flags from the gimbal but can also enhance the capabilities and thus add flags.

Implementations

Source

impl GimbalManagerCapFlags

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_RETRACT: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_RETRACT.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_NEUTRAL: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_NEUTRAL.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_ROLL_AXIS: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_ROLL_AXIS.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_ROLL_FOLLOW: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_ROLL_FOLLOW.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_ROLL_LOCK: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_ROLL_LOCK.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_PITCH_AXIS: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_PITCH_AXIS.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_PITCH_FOLLOW: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_PITCH_FOLLOW.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_PITCH_LOCK: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_PITCH_LOCK.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_YAW_AXIS: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_YAW_AXIS.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_YAW_FOLLOW: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_YAW_FOLLOW.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_YAW_LOCK: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_YAW_LOCK.

pub const GIMBAL_MANAGER_CAP_FLAGS_SUPPORTS_INFINITE_YAW: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_SUPPORTS_INFINITE_YAW.

pub const GIMBAL_MANAGER_CAP_FLAGS_SUPPORTS_YAW_IN_EARTH_FRAME: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_SUPPORTS_YAW_IN_EARTH_FRAME.

pub const GIMBAL_MANAGER_CAP_FLAGS_HAS_RC_INPUTS: Self

Based on GIMBAL_DEVICE_CAP_FLAGS_HAS_RC_INPUTS.

pub const GIMBAL_MANAGER_CAP_FLAGS_CAN_POINT_LOCATION_LOCAL: Self

Gimbal manager supports to point to a local position.

pub const GIMBAL_MANAGER_CAP_FLAGS_CAN_POINT_LOCATION_GLOBAL: Self

Gimbal manager supports to point to a global latitude, longitude, altitude position.

Source

impl GimbalManagerCapFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl GimbalManagerCapFlags

pub const fn iter(&self) -> Iter<GimbalManagerCapFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<GimbalManagerCapFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl GimbalManagerCapFlags

pub const DEFAULT: Self = Self::GIMBAL_MANAGER_CAP_FLAGS_HAS_RETRACT