pub struct LOCAL_POSITION_NED_COV_DATA {
pub time_usec: u64,
pub x: f32,
pub y: f32,
pub z: f32,
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub ax: f32,
pub ay: f32,
pub az: f32,
pub covariance: [f32; 45],
pub estimator_type: MavEstimatorType,
}dialect-ualberta only.Expand description
The filtered local position (e.g. fused computer vision and accelerometers). Coordinate frame is right-handed, Z-axis down (aeronautical frame, NED / north-east-down convention).
ID: 64
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
x: f32X Position
y: f32Y Position
z: f32Z Position
vx: f32X Speed
vy: f32Y Speed
vz: f32Z Speed
ax: f32X Acceleration
ay: f32Y Acceleration
az: f32Z Acceleration
covariance: [f32; 45]Row-major representation of position, velocity and acceleration 9x9 cross-covariance matrix upper right triangle (states: x, y, z, vx, vy, vz, ax, ay, az; first nine entries are the first ROW, next eight entries are the second row, etc.). If unknown, assign NaN value to first element in the array.
estimator_type: MavEstimatorTypeClass id of the estimator this estimate originated from.
Implementations