pub struct OPTICAL_FLOW_RAD_DATA {
pub time_usec: u64,
pub integration_time_us: u32,
pub integrated_x: f32,
pub integrated_y: f32,
pub integrated_xgyro: f32,
pub integrated_ygyro: f32,
pub integrated_zgyro: f32,
pub time_delta_distance_us: u32,
pub distance: f32,
pub temperature: i16,
pub sensor_id: u8,
pub quality: u8,
}dialect-ualberta only.Expand description
Optical flow from an angular rate flow sensor (e.g. PX4FLOW or mouse sensor).
ID: 106
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
integration_time_us: u32Integration time. Divide integrated_x and integrated_y by the integration time to obtain average flow. The integration time also indicates the.
integrated_x: f32Flow around X axis (Sensor RH rotation about the X axis induces a positive flow. Sensor linear motion along the positive Y axis induces a negative flow.)
integrated_y: f32Flow around Y axis (Sensor RH rotation about the Y axis induces a positive flow. Sensor linear motion along the positive X axis induces a positive flow.)
integrated_xgyro: f32RH rotation around X axis
integrated_ygyro: f32RH rotation around Y axis
integrated_zgyro: f32RH rotation around Z axis
time_delta_distance_us: u32Time since the distance was sampled.
distance: f32Distance to the center of the flow field. Positive value (including zero): distance known. Negative value: Unknown distance.
temperature: i16Temperature
sensor_id: u8Sensor ID
quality: u8Optical flow quality / confidence. 0: no valid flow, 255: maximum quality
Implementations