pub struct UAVCAN_NODE_INFO_DATA {
pub time_usec: u64,
pub uptime_sec: u32,
pub sw_vcs_commit: u32,
pub name: CharArray<80>,
pub hw_version_major: u8,
pub hw_version_minor: u8,
pub hw_unique_id: [u8; 16],
pub sw_version_major: u8,
pub sw_version_minor: u8,
}dialect-ualberta only.Expand description
General information describing a particular UAVCAN node. Please refer to the definition of the UAVCAN service “uavcan.protocol.GetNodeInfo” for the background information. This message should be emitted by the system whenever a new node appears online, or an existing node reboots. Additionally, it can be emitted upon request from the other end of the MAVLink channel (see MAV_CMD_UAVCAN_GET_NODE_INFO). It is also not prohibited to emit this message unconditionally at a low frequency. The UAVCAN specification is available at http://uavcan.org.
ID: 311
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
uptime_sec: u32Time since the start-up of the node.
sw_vcs_commit: u32Version control system (VCS) revision identifier (e.g. git short commit hash). 0 if unknown.
name: CharArray<80>Node name string. For example, “sapog.px4.io”.
hw_version_major: u8Hardware major version number.
hw_version_minor: u8Hardware minor version number.
hw_unique_id: [u8; 16]Hardware unique 128-bit ID.
sw_version_major: u8Software major version number.
sw_version_minor: u8Software minor version number.
Implementations